Main features
-------------

- Intuitive representation of locations on Earth (Sect. :ref:`geopoint`).
- Intuitive representation of geodesic connections (Sect. :ref:`geovector`).
- Tools for setting up geographic domains (Sect. :ref:`geosetup`).
- Tools for importing and representing topographic datasets (Sect.
  :ref:`topodata`)
- Computation and post analysis of topographic elevation profiles (Sect.
  :ref:`elevationprofiles`).
- Helpers to compute meteorological parameters (Sect. :ref:`atmosphere`).
- Computation of intersections with other locations or topographic terrain.
- Automatic access to `NASA SRTM topographic dataset <https://www2.jpl.nasa.gov/srtm/>`__.
- Support for import of `NOAA ETOPO1 topographic dataset <https://ngdc.noaa.gov/mgg/global/global.html>`__.

